Range-v3: ranges::v3::concepts::SemiContainer Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::SemiContainer Struct Reference
Inheritance diagram for ranges::v3::concepts::SemiContainer:

## Public Member Functions
template<typename T >
auto | requires_ () -> decltype(concepts::valid_expr(concepts::model_of< DefaultConstructible, uncvref_t< T >>(), concepts::model_of< Movable, uncvref_t< T >>(), concepts::is_false(is_view< T >())))
Public Member Functions inherited from ranges::v3::concepts::refines< ForwardRange >
void | requires_ ()

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< ForwardRange >
using | base_concepts_t = meta::list< Concepts... >